@@ -2,14 +2,14 @@ from typing import Any, Dict, List, Optional, Union
 
 import dask.dataframe as dd
 import pandas as pd
-from dagster import Field, Noneable, Permissive
+from dagster import Field, Noneable, Permissive, StringSource
 from qdk.loader.dataframe import DataFrameLoader
 
 
 class SqlTableLoader(DataFrameLoader):
     config_schema = {
         "connection_uri": Field(
-            str,
+            StringSource,
             description="The SqlAlchemy connection uri. (postgresql://user:password@host:port/database)",
         ),
         "table": Field(
